@@ -1,6 +1,9 @@
 # Environments where server url and api key are stored for global connection
 SERVER_URL_ENV_KEY = "AYON_SERVER_URL"
 SERVER_API_ENV_KEY = "AYON_API_KEY"
+SERVER_TIMEOUT_ENV_KEY = "AYON_SERVER_TIMEOUT"
+SERVER_RETRIES_ENV_KEY = "AYON_SERVER_RETRIES"
+
 # Backwards compatibility
 SERVER_TOKEN_ENV_KEY = SERVER_API_ENV_KEY
 
