@@ -33,6 +33,16 @@ class ServerNotReached(ServerError):
     pass
 
 
+class RequestError(Exception):
+    def __init__(self, message, response):
+        self.response = response
+        super(RequestError, self).__init__(message)
+
+
+class HTTPRequestError(RequestError):
+    pass
+
+
 class GraphQlQueryFailed(Exception):
     def __init__(self, errors, query, variables):
         if variables is None:
@@ -94,4 +104,4 @@ class FailedOperations(Exception):
 
 
 class FailedServiceInit(Exception):
-    pass
\ No newline at end of file
+    pass
